pub struct SemanticFunctionTypeParameter {
pub kind: ParameterKind,
pub static_type: Thingy,
}Expand description
Parameter belonging to a function type in the semantic model.
Fields
kind: ParameterKindstatic_type: ThingyStatic type of the parameter. It is never UnresolvedThingy
as function types are only created after all compound types
are resolved.
Implementations
Sourceimpl SemanticFunctionTypeParameter
impl SemanticFunctionTypeParameter
Sourcepub fn type_substitution(
&self,
host: &SemanticHost,
type_params: &SharedArray<Thingy>,
substitute_types: &SharedArray<Thingy>,
) -> Self
pub fn type_substitution( &self, host: &SemanticHost, type_params: &SharedArray<Thingy>, substitute_types: &SharedArray<Thingy>, ) -> Self
Performs type substitution.